@@ -1,6 +1,6 @@
 /*
   This file is part of gnunet-fuse.
-  (C) 2012 Christian Grothoff (and other contributing authors)
+  Copyright (C) 2012 GNUnet e.V.
   
   gnunet-fuse is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
@@ -14,7 +14,7 @@
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 */
 /*
@@ -76,7 +76,7 @@ gn_read (const char *path, char *buf, size_t size, off_t offset,
 						offset,
 						size))
     {
-      UNLINK (path_info->tmpfile);
+      unlink (path_info->tmpfile);
       GNUNET_free (path_info->tmpfile);
       path_info->tmpfile = NULL;
       GNUNET_FUSE_path_info_done (path_info);
@@ -93,7 +93,7 @@ gn_read (const char *path, char *buf, size_t size, off_t offset,
 						  offset,
 						  size))
       {
-	UNLINK (path_info->tmpfile);
+	unlink (path_info->tmpfile);
 	GNUNET_free (path_info->tmpfile);
 	path_info->tmpfile = NULL;
 	GNUNET_FUSE_path_info_done (path_info);
@@ -154,7 +154,7 @@ gn_read (const char *path, char *buf, size_t size, off_t offset,
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, 
 		"Error reading from file `%s': %s\n",
 		path,
-		STRERROR (errno));
+		strerror (errno));
     GNUNET_DISK_file_close (fh);
     GNUNET_FUSE_path_info_done (path_info);
     return - eno; 
